*###########################################################################################
*### Balance Figure  

*### PATHS (Put the file path where you downloaded the contents of the zip file)
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
global path 	"..../Example3/"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*### VERSION TRACK
/*
Created by Pavel Luengas
Last update: Nov 18, 2022

Version 1.0 - Nov 18, 2022
    File created 

Contact me for comments and questions:
pavel@pavellsierra.com */

*===========================================================================================

version 14
set more off

*####################################### 
*### Step 1: Explore the dataset

use "$path/Dataset", clear

sum ind1-ind20, sep(5)
* Note that variables 13 and 14 have missing values. 
* For both variables, missing values are valid (eg. the variables are characteristics of a subgroup)
* Variables 3 to 5 have missing observations (eg not reported), but just for 1 of 691 observations

tab treatassign

forvalues g = 0/2 {
    display "Treatment group = `g' | 0 Control & Surveyed, 1 Treatment & Surveyed"
    sum ind1-ind20 if treatassign==`g', sep(0)    
}

*################################################ 
*### Step 2: Standardized differences between 
*## (1) Treatment & (0) Control AND
*## (1) Treatment & (2) Control not surveyed

gen 	Ta = .
replace Ta = 1 if treatassign==1
replace Ta = 0 if treatassign==0

gen 	Tb = .
replace Tb = 1 if treatassign==1
replace Tb = 0 if treatassign==2

* We consider 20 indicators. Create two matrices, one per comparison
* NOTE: All 20 indicators point towards the same direction, higher values denoting better attributes

matrix MTa = J(20,1,.)
matrix MTb = J(20,1,.)

*# Standardized difference: Example

* Control group
sum ind10  if Ta ==0
    local m0 =r(mean) // Mean
    local v0 =r(Var) // Variance

* Treatment group 
sum ind10  if Ta ==1
    local m1 =r(mean) // Mean
    local v1 =r(Var) // Variance

gen stdif_10 = (`m1' - `m0') / (((`v1'+`v0')/2)^.5)

sum stdif_10
drop stdif_10

*# Standardized difference: Loop

foreach type in Ta Tb {
	forvalues i=1/20 {    
	    forvalues j=0/1 {
	    qui sum ind`i' if `type' ==`j'
	        local m`j' =r(mean)
	        local v`j' =r(Var)
	    }
	local stdif`i' = (`m1' - `m0') / (((`v1'+`v0')/2)^.5)
    matrix M`type'[`i',1] = `stdif`i''
	}
}

matrix list MTa
matrix list MTb

matrix MGraph = MTa, MTb
matrix colnames MGraph = a b

* Number of communities
count
scalar Coms = r(N)
*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*################################################ 
*### Step 3: Create graph

clear 
svmat MGraph, names(col)

* We want the first indicator at top rather than at bottom
gen obs= _N-_n+1

* Scalar to local
local NComs = Coms 
di "`NComs'"

set scheme s1mono // Get rid of all color

twoway  /*
    */ /*
    */ (scatter   obs a, msymbol(O)  mfcolor(none) mlcolor(dknavy) mlwidth(vthin) msize(small)  ) /*
    */ (scatter   obs b, msymbol(S)  mfcolor(none) mlcolor(dknavy) mlwidth(vthin) msize(small)  ) /*
    */ , /*
    */ plotr(m(zero)) plotregion(lwidth(none)) /*   
    */ aspect(3) /* 
    */   /*
    */ title("Communities"  "(n=`NComs')"  " " , size(vsmall)) /*
    */   /*
    */ ytitle(" ", size(vsmall)) /*
    */ yscale(range(0.5 20.5) lcolor(white) lwidth(none)) /*
    */ ylabel(  /* 
    */        1  `" "- Own label [c12]" "'   /*    
    */        2  `" "- Own label [c11]" "'   /*    
    */        3  `" "- Own label [c10]"   "'   /*    
    */        4  `" "- Own label [c9]"   "'   /*    
    */        5  `" "- Own label [c8]" "'   /*    
    */        6  `" "- Own label [c7]" "'   /*    
    */        7  `" "- Own label (if charges fees) [c6]" "'   /*    
    */        8  `" "- Own label (if charges fees) [c5]" "'   /*    
    */        9  `" "- Charges fees [c4]" "'   /*    
    */        10 `" "- Own label [c3]" "'   /*    
    */        11 `" "- Own label [c2]"  "'   /*        
    */        12 `" "- Own label [c1]"  "'   /*        
    */        13 `" "- Own label  [b4]"  "'   /*    
    */        14 `" "- Own label [b3]" "'   /*    
    */        15 `" "- Own label [b2]"  "'  /*    
	*/        16 `" "- Own label [b1]"  "'  /*    
	*/        17 `" "- Own label [a4]"  "'  /*    
	*/        18 `" "- Own label [a3]"  "'  /*    
	*/        19 `" "- Own label [a2]"  "'  /*    
    */        20 `" "- Own label [a1]"  "'  /*    
    */ , labsize(vsmall) labcolor(black) angle(horizontal) tlwidth(vthin))    /*
    */   /*
    */ xtitle(" " "Standardized Difference" " ({&mu}{subscript:1}-{&mu}{subscript:2}) / {&sqrt}[(Var{subscript:1}+Var{subscript:2})/2] ", size(vsmall)) /*    */ xscale(range(-1.0 1.0)  lwidth(vthin)) /*
    */ xlabel(-1.0 "-1.0" -.5 "-0.5" 0 "0" .5 "+0.5" 1 "+1.0", labsize(vsmall) tlwidth(vthin))    /*
    */   /*
    */ xline(0.00, lwidth(vthin) lcolor(cranberry) lpattern(solid)) /*
    */   /*
    */ xline(-0.20, lwidth(vthin) lcolor(edkblue) lpattern(dash)) /*
    */ xline(+0.20, lwidth(vthin) lcolor(edkblue) lpattern(dash)) /*
    */ text(20.7 0.00 "{&plusmn}0.20", placement(n) size(vsmall)) /*
    */ /* 
    */ /* 
    */ yline(20.5, lwidth(vthin) lcolor(black) lpattern(solid)) /*
    */ yline(16.5, lwidth(vthin) lcolor(black) lpattern(solid)) /*
    */ yline(12.5, lwidth(vthin) lcolor(black) lpattern(solid)) /*
    */ /* 
    */ text(18.5 -.8 "{it:Group A}", placement(w) box bcolor(white)  orient(vertical) size(vsmall)) /*
    */ text(14.5 -.8 "{it:Group B}", placement(w) box bcolor(white)  orient(vertical) size(vsmall)) /*
    */ text(6.5 -.8  "{it:Group C}", placement(w) box bcolor(white)  orient(vertical) size(vsmall)) /*
    */ /* 
    */ /* 
	*/ legend(on region(style(none) ) /*
	*/ colgap(1)  bmargin(0 0 0 0 ) /*
	*/ symxsize(2) symysize(2) keygap(1) /*
	*/ size(vsmall) order(1 2)  /*
	*/ label(1 "Treatment-Control (S)") /*
	*/ label(2 "Treatment-Control (NS)") /*
	*/ col(1) ) 

graph export "$path/Figs/Balance.eps", replace 
graph save Graph "$path/Graph.gph", replace

